@@ -5,18 +5,8 @@ PermissionsX - Authorization for Django.
 :license:   BSD, see LICENSE for more details.
 
 """
-import sys
-
-VERSION = (1, 0, 0)
+VERSION = (1, 1, 0)
 
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Robert Pogorzelski <thinkingpotato@gmail.com>"
 __docformat__ = "restructuredtext"
-
-if sys.version_info < (2, 7):
-    import warnings
-    warnings.warn(DeprecationWarning("""
-
-Only version 2.7 of Python is currently supported.
-
-"""))
