@@ -7,6 +7,8 @@ PermissionsX - Authorization for Django.
 """
 from __future__ import absolute_import
 
+import logging
+
 from django import template
 from django.contrib import auth
 from django.views.generic import RedirectView as DjangoRedirectView
@@ -20,6 +22,9 @@ from permissionsx import settings
 from permissionsx.utils import get_class
 
 
+logger = logging.getLogger('permissionsx')
+
+
 class RedirectView(DjangoRedirectView):
 
     permanent = False
@@ -55,6 +60,9 @@ class DjangoViewMixin(object):
     def dispatch(self, request, *args, **kwargs):
         if hasattr(self, 'permissions_class'):
             permissions = self.permissions_class()
+            if settings.PERMISSIONSX_DEBUG:
+                logger.debug('View class: {}'.format(self.__class__.__name__))
+                logger.debug('View permissions class: {}'.format(permissions.__class__.__name__))
             if permissions.check_permissions(request, **kwargs):
                 return super(DjangoViewMixin, self).dispatch(request, *args, **kwargs)
             elif settings.PERMISSIONSX_LOGOUT_IF_DENIED:
@@ -63,7 +71,6 @@ class DjangoViewMixin(object):
         return super(DjangoViewMixin, self).dispatch(request, *args, **kwargs)
 
 
-
 class DummyRequest(object):
 
     user = None
